<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xpath-default-namespace="http://www.tei-c.org/ns/1.0"  version="2.0">
    
    <xsl:template match="/TEI">
        <html>
            <head>
                <title>BD6776-crit</title>
                <meta name="date" content="2009-06"/>
                <meta name="author" content="marcus bingenheimer"/>
                <meta name="keywords" content="manuscript, markup, TEI, Dunhuang, Buddhism"/>
                <meta http-equiv="content-type" content="text/html; charset=UTF-8"/>
                <style type="text/css">
                    * {background-color: efefef}
                    a {vertical-align:super; font-size: smaller; text-decoration:none;}
                    .verse {margin-left:3%; color:green}
                    .supplied {color:magenta}
                    .apparatus {font-size:smaller; color: 555}
                    .gaiji {text-decoration:none; vertical-align:baseline; font-size: medium; color:blue}
                </style>
            </head>
            <body>   
                <script type="text/javascript" src="wz_tooltip/wz_tooltip.js"></script>
                <p style="width:20%; float:right;" id="imageHook">Hook</p>
                <h3>
                    This output tends towards a "text critical" edition of BD 6776
                </h3>
                <p>The idea is to have as many apparatus and annotation as we want. If one is ready to cut the digital facsimile, line-by-line view is convenient.</p>
               <xsl:apply-templates/>
                <div><hr/>
                    <h3>Beijing Dunhuang 6776 apparatus (print look-alike):</h3>                    
                    <xsl:apply-templates select="//div[@type='text']//app" mode="BDapp"/></div>
                <div> <hr/>
                    <h3>CBETA apparatus (print look-alike):</h3>
                    <xsl:apply-templates select="//div[@type='apparatus']//app" mode="CBETAapp"/></div>
            </body>
        </html>        
    </xsl:template>
    
    <!-- silence the header -->
    <xsl:template match="teiHeader"/>
    
    <xsl:template match="div[@type = 'sutra'] | div[@type = 'uddana']">
        <div class="{@type}"><a href="BD6776/{@facs}" title="image of the manuscript">{圖(dumb)}</a>
        <xsl:apply-templates/></div>
    </xsl:template>
    
    <xsl:template match="lg | p">        
           <xsl:apply-templates/>
     </xsl:template>
    
    <!-- Line breaks follow the Ms (@ed='BD'). 
        IF there is a facs attribute in the markup, we want to see the image on mouseover (using JS pop-ups) -->
    <xsl:template match="lb[@ed='BD']">
        <xsl:choose>
            <xsl:when test="@facs">
                <br/> [<xsl:value-of select="substring-after(@n, '-')"/>] <a  onmouseout="UnTip()" onmouseover="Tip('&lt;img src=&quot;BD6776/{@facs}&quot;/>', WIDTH, 70, PADDING, 2, BGCOLOR, '#efefef', FIX,['imageHook', 0, 0])" href="javascript:void(0)">{圖}</a>&#x00A0;
            </xsl:when>
            <!-- otherwise just insert a linebreak and write the number -->
            <xsl:otherwise><br/> [<xsl:value-of select="substring-after(@n, '-')"/>] &#x00A0;</xsl:otherwise>
        </xsl:choose>        
    </xsl:template>    
    
    
    
    <!-- Here are two different (print look-alike) apparatus: one created for this BD Ms, the other legacy from CBETA. This just for reference. For html transforms like this print look-alikes should be considered depreciated. I recommend using JS pop-ups to offer annotation on mouseclick or mouseover. That way annotation and annotated passage can be viewed together. -->
    
    <!-- create the BD app -->
    <xsl:template match="div[@type='text']//app" mode="BDapp">
       <p>
           <a id="BDapp{count(preceding::app)+1}" href="#BD{count(preceding::app)+1}">[bd<xsl:value-of select="count(preceding::app)+1"/>]</a>
           <xsl:value-of select="lem"/> is:            
        <xsl:for-each select="rdg">
            <xsl:value-of select="."/> in <xsl:value-of select="@wit"/>.
        </xsl:for-each></p>
    </xsl:template>
    
    <!-- this silences the apparatus without mode -->
    <xsl:template match="div[@type='apparatus']/p/app"/> 
    
    <!-- create the CBETA apparatus -->
    <xsl:template match="div[@type='apparatus']/p/app" mode="CBETAapp">
        <p><a id="CBETAapp{@from}" href="#CBETA{@from}">[cb<xsl:value-of select="count(preceding-sibling::app)+1"/>]</a><xsl:value-of select="lem"/> is:            
            <xsl:for-each select="rdg">
                <xsl:value-of select="."/> in <xsl:value-of select="@wit"/>.
            </xsl:for-each></p>
    </xsl:template>
    
    <!-- These two create the reference number for the two apparatus in the text -->
    <xsl:template match="anchor[contains(@xml:id, 'beg')]">
        <xsl:variable name="str">
            <xsl:value-of select="//app[@from = current()/@xml:id]/rdg"/> in 
            <xsl:value-of select="//app[@from = current()/@xml:id]/rdg/@wit"/>
        </xsl:variable>
        <a  id="CBETA{@xml:id}" href="#CBETAapp{@xml:id}" title="{$str}">
            [cb<xsl:value-of select="count(preceding::anchor)+1"/>]
        </a>
    </xsl:template>
    
      <!-- this puts in the lem after the fn number. Here we use JS mouseover popups. -->
    <xsl:template match="div[@type='text']//app">        
        <a id="BD{count(preceding::app)+1}" href="#BDapp{count(preceding::app)+1}">[bd<xsl:value-of select="count(preceding::app)+1"/>] </a>
        <xsl:element name="a">
            <xsl:attribute name="class">gaiji</xsl:attribute>
            <xsl:attribute name="href">javascript:void(0)</xsl:attribute>
            <xsl:attribute name="onmouseout">UnTip()</xsl:attribute>
            <!-- the syntax for this JS call depends on the library you are using. Here we use Walter Zorn's JS pop-ups (referenced in the HTML right after the BODY tag) -->
            <xsl:attribute name="onmouseover">Tip('<xsl:for-each select="rdg">
                    <xsl:value-of select="@wit"/> has <xsl:value-of select="."/>
                   <xsl:if test="position() != last()">&lt;br/&gt;</xsl:if></xsl:for-each>')
            </xsl:attribute>
            <xsl:apply-templates select="lem"/>
        </xsl:element>
    </xsl:template>
    
    <!-- Insert regularized version for Gaiji, provide enlarged scan of the original  -->
    <xsl:template match="g">
        <xsl:variable name="reg">
            <xsl:value-of select="/TEI/teiHeader/encodingDesc/charDecl/glyph[@xml:id =current()/@ref]/mapping[@type='regular']"/>
        </xsl:variable>
        <xsl:variable name="img">
            <xsl:value-of select="/TEI/teiHeader/encodingDesc/charDecl/glyph[@xml:id =current()/@ref]/graphic/@url"/>
        </xsl:variable> 
        <xsl:choose> 
            <xsl:when test="text()">
                <span style="color:red"><a class="gaiji" onmouseout="UnTip()" onmouseover="Tip('Normalized form of: &lt;br/>&lt;img src=&quot;{$img}&quot; width=&quot;150&quot; height=&quot;102&quot;>', WIDTH, 150, PADDING, 6, BGCOLOR, '#ffffff')" href="javascript:void(0);"><xsl:value-of select="."/></a></span>
            </xsl:when>
            <xsl:otherwise>
                <span style="color:red"><a class="gaiji" onmouseout="UnTip()" onmouseover="Tip('Normalized form of: &lt;br/>&lt;img src=&quot;{$img}&quot; width=&quot;150&quot; height=&quot;102&quot;>', WIDTH, 150, PADDING, 6, BGCOLOR, '#ffffff')" href="javascript:void(0);"><xsl:value-of select="$reg"/></a></span>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="supplied">        
        <span class="supplied">
            <xsl:text>[</xsl:text><xsl:value-of select="./text()"/><xsl:text>]</xsl:text>
            <a onmouseout="UnTip()" onmouseover="Tip('{note}', ABOVE, true, WIDTH, 150, PADDING, 3)" href="javascript:void(0);">[note]</a>
        </span>        
    </xsl:template>    
    
    <xsl:template match="l">
        <span class="verse"><xsl:apply-templates/></span>
    </xsl:template>
    <xsl:template match="caesura">
        &#x00A0;&#x00A0;
    </xsl:template>
       
</xsl:stylesheet>
